@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for forecastquery service client
 
@@ -7,17 +8,14 @@ Usage::
     import boto3
     from mypy_boto3_forecastquery import ForecastQueryServiceClient
 
-    session = boto3.Session()
-
     client: ForecastQueryServiceClient = boto3.client("forecastquery")
-    session_client: ForecastQueryServiceClient = session.client("forecastquery")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Any, Dict, TYPE_CHECKING, Type
-from botocore.exceptions import ClientError as Boto3ClientError
-from mypy_boto3_forecastquery.type_defs import QueryForecastResponseTypeDef
+from typing import Any, Dict, Type
 
+from botocore.exceptions import ClientError as Boto3ClientError
+
+from mypy_boto3_forecastquery.type_defs import QueryForecastResponseTypeDef
 
 __all__ = ("ForecastQueryServiceClient",)
 
@@ -33,14 +31,14 @@ class Exceptions:
 
 class ForecastQueryServiceClient:
     """
-    [ForecastQueryService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/forecastquery.html#ForecastQueryService.Client)
+    [ForecastQueryService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/forecastquery.html#ForecastQueryService.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -51,7 +49,7 @@ class ForecastQueryServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
         """
 
     def query_forecast(
@@ -63,5 +61,5 @@ class ForecastQueryServiceClient:
         NextToken: str = None,
     ) -> QueryForecastResponseTypeDef:
         """
-        [Client.query_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
+        [Client.query_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
         """
